# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		libmetalink
Version:	0.1.3
Release:	31.%{__distinit}%{__distvers}
Summary:	Metalink library written in C
License:	MIT
URL:		https://launchpad.net/libmetalink
Source:		https://launchpad.net/libmetalink/trunk/libmetalink-%{version}/+download/libmetalink-%{version}.tar.bz2
Patch0:		https://bugs.launchpad.net/libmetalink/+bug/1888672/+attachment/5395227/+files/libmetalink-0.1.3-ns_uri.patch
Patch1:		https://bugs.launchpad.net/libmetalink/+bug/1784359/+attachment/5169495/+files/0001-fix-covscan-issues.patch
BuildRequires:	coreutils
BuildRequires:	CUnit-devel
BuildRequires:	expat-devel
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make

# %%make_build only defined from EL-7, F-21 onwards
%{!?make_build:%global make_build make %{_smp_mflags}}

%description
libmetalink is a Metalink C library. It adds Metalink functionality such as
parsing Metalink XML files to programs written in C.

%package	devel
Summary:	Files needed for developing with libmetalink
Requires:	libmetalink%{?_isa} = %{version}-%{release}

%description	devel
Files needed for building applications with libmetalink.

%prep
%setup -q

# Fix NULL ptr deref in initial_state_start_fun
# https://bugs.launchpad.net/libmetalink/+bug/1888672
# https://bugzilla.redhat.com/show_bug.cgi?id=1860976
%patch -P 0 -p1

# Fix a few issues found by the Coverity static analysis tool
# https://bugs.launchpad.net/libmetalink/+bug/1784359
# https://github.com/metalink-dev/libmetalink/pull/2
%patch -P 1 -p1

%build
%configure --disable-static
%{make_build}

%install
%{make_install}
find %{buildroot} -name *.la -delete

%check
make check

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig replaced by RPM File Triggers from Fedora 28
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/libmetalink.so.3
%{_libdir}/libmetalink.so.3.*

%files devel
%dir %{_includedir}/metalink/
%{_includedir}/metalink/metalink_error.h
%{_includedir}/metalink/metalink.h
%{_includedir}/metalink/metalink_parser.h
%{_includedir}/metalink/metalink_types.h
%{_includedir}/metalink/metalinkver.h
%{_libdir}/libmetalink.so
%{_libdir}/pkgconfig/libmetalink.pc
%{_mandir}/man3/metalink_checksum_t.3*
%{_mandir}/man3/metalink_chunk_checksum_t.3*
%{_mandir}/man3/metalink_delete.3*
%{_mandir}/man3/metalink_file_t.3*
%{_mandir}/man3/metalink_parse_fd.3*
%{_mandir}/man3/metalink_parse_file.3*
%{_mandir}/man3/metalink_parse_final.3*
%{_mandir}/man3/metalink_parse_fp.3*
%{_mandir}/man3/metalink_parse_memory.3*
%{_mandir}/man3/metalink_parse_update.3*
%{_mandir}/man3/metalink_parser_context_delete.3*
%{_mandir}/man3/metalink_parser_context_new.3*
%{_mandir}/man3/metalink_piece_hash_t.3*
%{_mandir}/man3/metalink_resource_t.3*
%{_mandir}/man3/metalink_t.3*

%changelog
* Mon May 29 2023 Paul Howarth <paul@city-fan.org> - 0.1.3-31
- Do not number the sole Source
- Avoid use of deprecated patch syntax

* Fri Jan 20 2023 Paul Howarth <paul@city-fan.org> - 0.1.3-30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Oct 19 2022 Paul Howarth <paul@city-fan.org> - 0.1.3-29
- Note: license is SPDX: MIT

* Sun Jul 24 2022 Paul Howarth <paul@city-fan.org> - 0.1.3-28
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Thu Apr 21 2022 Paul Howarth <paul@city-fan.org> - 0.1.3-27
- Rebuild to sync with rawhide

* Mon Jan 24 2022 Paul Howarth <paul@city-fan.org> - 0.1.3-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jan 13 2022 Paul Howarth <paul@city-fan.org> - 0.1.3-24
- Fix a few issues found by the Coverity static analysis tool
  https://bugs.launchpad.net/libmetalink/+bug/1784359
  https://github.com/metalink-dev/libmetalink/pull/2
- Package the AUTHORS, ChangeLog and NEWS files

* Thu Jul 22 2021 Paul Howarth <paul@city-fan.org> - 0.1.3-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
- Fix dist tags for Alma and Rocky Linux

* Thu Jan 28 2021 Paul Howarth <paul@city-fan.org> - 0.1.3-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Aug  4 2020 Paul Howarth <paul@city-fan.org> - 0.1.3-13
- Fix NULL ptr deref in initial_state_start_fun
  https://bugs.launchpad.net/libmetalink/+bug/1888672
  https://bugzilla.redhat.com/show_bug.cgi?id=1860976

* Tue Jul 28 2020 Paul Howarth <paul@city-fan.org> - 0.1.3-12
- Use %%{make_build} and %%{make_install}

* Fri Jan 31 2020 Paul Howarth <paul@city-fan.org> - 0.1.3-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Paul Howarth <paul@city-fan.org> - 0.1.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Feb  5 2019 Paul Howarth <paul@city-fan.org> - 0.1.3-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Jul 17 2018 Paul Howarth <paul@city-fan.org> - 0.1.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 14 2018 Paul Howarth <paul@city-fan.org> - 0.1.3-6
- ldconfig replaced by RPM File Triggers from Fedora 28
- BR: CUnit-devel unconditionally
- Work around presence of incompatible expat21 in EPEL-6

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 0.1.3-4
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Feb 11 2017 Paul Howarth <paul@city-fan.org> - 0.1.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Nov 16 2016 Paul Howarth <paul@city-fan.org> - 0.1.3-1
- Update to 0.1.3
  - Fixes a bug in which the signature element in metalink v4 was not parsed
    correctly

* Fri Feb  5 2016 Paul Howarth <paul@city-fan.org> - 0.1.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jun 20 2015 Paul Howarth <paul@city-fan.org> - 0.1.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 0.1.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jul 21 2014 Paul Howarth <paul@city-fan.org> - 0.1.2-6
- Use %%license where possible

* Wed Jun 11 2014 Paul Howarth <paul@city-fan.org> - 0.1.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Jun 26 2013 Paul Howarth <paul@city-fan.org> - 0.1.2-4
- Import from Fedora

* Thu Jun 13 2013 Alejandro Alvarez <aalvarez@cern.ch> - 0.1.2-3
- Added BuildRequires: CUnit-devel
- Added %%check section
- Removed %%defattr
- Moved man pages to devel package; there is no need for -doc

* Mon Jun 10 2013 Alejandro Alvarez <aalvarez@cern.ch> - 0.1.2-2
- Escaped macros in changelog
- Changed packages summaries
- Renamed -docs to -doc, and changed its group to Documentation
- Fixed -devel dependencies
- Removed -docs dependency on the main package
- All header files specified explicitly

* Mon Apr 22 2013 Alejandro Alvarez <aalvarez@cern.ch> - 0.1.2-1
- Updated for new upstream release
- Man pages moved to libmetalink-docs package

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu May 07 2009 Ant Bryan <anthonybryan at gmail.com> - 0.0.3-4
- Remove Provides: libmetalink-static = %%{version}-%%{release}

* Wed May 06 2009 Ant Bryan <anthonybryan at gmail.com> - 0.0.3-3
- Use %%{_docdir} instead of /usr/share/doc
- Own /usr/include/metalink

* Wed Apr 29 2009 Ant Bryan <anthonybryan at gmail.com> - 0.0.3-2
- Incorporate suggested changes: remove .la files, --disable static

* Mon Apr 27 2009 Ant Bryan <anthonybryan at gmail.com> - 0.0.3-1
- Initial package, 0.0.3

